@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 package XML::BindData;
-$XML::BindData::VERSION = '0.1.0';
+$XML::BindData::VERSION = '0.1.1';
 use XML::LibXML;
 
 sub bind {
@@ -20,31 +20,33 @@ sub parse_node {
 	if (my $if_key = _strip_attr($node, 'tmpl-if')) {
 		my $unless = $if_key =~ s/^!//;
 		my $val    = _get($context, $if_key);
-		if (   (!$unless && !$val)
-			|| ( $unless &&  $val)) {
+		if ( (!$unless && ! defined $val)
+			|| ( $unless &&  defined $val)) {
 			$node->unbindNode;
 		}
 	}
 
 	if (my $each_key = _strip_attr($node, 'tmpl-each')) {
 		my $parent = $node->parentNode;
-		$node->unbindNode;
 
 		my $to_add = _get($context, $each_key);
 		if (!$to_add || ref $to_add ne 'ARRAY') {
 			$to_add = [];
 		}
 
-		foreach my $subcontext (@$to_add) {
+		foreach my $subcontext ( reverse @$to_add ) {
 			my $new = $node->cloneNode(1); # deep clone
 			parse_node($new, $subcontext);
-			$parent->appendChild($new);
+			$parent->insertAfter( $new, $node );
 		}
+		$node->unbindNode;
 		return;
 	}
 
 	if (my $binding = _strip_attr($node, 'tmpl-bind')) {
-		my $val = _get($context, $binding) || '';
+		my $val = _get($context, $binding);
+		$val = '' unless defined $val;
+
 		$node->appendTextNode($val);
 	}
 
@@ -267,5 +269,7 @@ attributes can be assigned at a time, separated by commas.
 
 =item Gareth Harper - GHARPER
 
+=item Chris Pereira
+
 =back
 
